pub enum TequelError {
InvalidHash,
InvalidHex(String),
InvalidMac,
InvalidUtf8,
KeyError(String),
}Expand description
Enum that represents some Types of Error in Tequel.
Variants
InvalidHash
When Hash is invalid
InvalidHex(String)
When occurr some error with the decode from HEX to UTF-8
InvalidMac
When MACs not match
InvalidUtf8
When occurr error while trying decode HEX to UTF-8
KeyError(String)
When key is don’t provided or is different